@@ -1,7 +1,7 @@
 package Perinci::Examples::FilePartial;
 
-our $DATE = '2014-12-03'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2015-01-04'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010;
 use strict;
@@ -13,7 +13,7 @@ our %SPEC;
 
 $SPEC{':package'} = {
     v => 1.1,
-    summary => 'Examples for reading/writing files',
+    summary => 'Examples for reading/writing files (demos partial argument/result)',
     description => <<'_',
 
 The functions in this package demoes partial content upload as well as partial
@@ -129,7 +129,7 @@ Perinci::Examples::FilePartial - Examples for reading/writing files (demos parti
 
 =head1 VERSION
 
-This document describes version 0.44 of Perinci::Examples::FilePartial (from Perl distribution Perinci-Examples), released on 2014-12-03.
+This document describes version 0.45 of Perinci::Examples::FilePartial (from Perl distribution Perinci-Examples), released on 2015-01-04.
 
 =head1 DESCRIPTION
 
@@ -162,8 +162,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -173,8 +171,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
+Return value:  (any)
 
 =head2 read_file(%args) -> [status, msg, result, meta]
 
@@ -186,8 +183,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -197,8 +192,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (buf)
-
+Return value:  (buf)
 
 =head2 write_file(%args) -> [status, msg, result, meta]
 
@@ -212,8 +206,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -223,15 +215,14 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
+Return value:  (any)
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
 
 =head1 BUGS
 
@@ -247,7 +238,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
